==> ep-framework-wordpress-1.2.4-856460.tar: src/Middleware/Bootstrap.php <==
<?php
namespace Ep\Wp\Middleware;

use Ep\Middleware\BaseUrl;
use Ep\Wp\Plugin\PluginInterface;
use Ep\Wp\Plugin\PluginManager;
use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ServerRequestInterface;
use Zend\Db\Adapter\AdapterInterface;
use Zend\Db\Adapter\Driver\Pdo\Pdo;

/**
 * Postavlja WordPress okruženje.
 *
 * @package Ep\Wp\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Bootstrap implements MiddlewareInterface
{
    /** @var array */
    private $config;
    /** @var AdapterInterface */
    private $db;
    /** @var PluginManager */
    private $pluginManager;
    /** @var PluginInterface  */
    private $plugins = [];

    /**
     * Config constructor.
     *
     * @param array $config
     * @param AdapterInterface $db
     */
    public function __construct(array $config, AdapterInterface $db, PluginManager $pluginManager)
    {
        $this->config = $config;
        $this->db     = $db;
        $this->pluginManager = $pluginManager;
    }

    /**
     * Inicijalizira WordPress.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        $this->database();
        $this->paths($request);
        $this->globals($request);
        $this->plugins();
        $this->includes();

        return $handler->handle($request);
    }

    /**
     * Postavlja bazu podataka.
     */
    private function database()
    {
        /** @var Pdo $driver */
        $driver = $this->db->getDriver();
        $params = $driver->getConnection()->getConnectionParameters();

        define('DB_NAME', $params['database'] ?? '');
        define('DB_USER', $params['username'] ?? '');
        define('DB_PASSWORD', $params['password'] ?? '');
        define('DB_HOST', $params['hostname'] ?? '');
        define('DB_CHARSET', 'utf8mb4');
        define('DB_COLLATE', 'utf8mb4_general_ci');
    }

    /**
     * Postavlja putanje i url-ove.
     *
     * @param ServerRequestInterface $request
     */
    private function paths(ServerRequestInterface $request)
    {
        $baseUrl = $request->getAttribute(BaseUrl::BASE_URL, '/');
        $baseUrl = preg_replace('#/wp(/wp-admin)?/?#', '', $baseUrl);

        $home = $request->getUri()
                        ->withPath($baseUrl)
                        ->withQuery('');

        define('WP_HOME', rtrim($home, '/'));
        define('WP_SITEURL', WP_HOME . '/wp');

        define('WP_CONTENT_DIR', dirname(ABSPATH) . '/wp-content');
        define('WP_CONTENT_URL', WP_HOME . '/wp-content');
    }

    /**
     * Inicijalizira globalne varijable.
     *
     * @param ServerRequestInterface $request
     */
    private function globals(ServerRequestInterface $request)
    { }

    /**
     * Inicijalizira vanjske pluginove.
     */
    private function plugins()
    {
        require_once ABSPATH . 'wp-includes/plugin.php';

        foreach ($this->config['plugins'] as $name) {
            $plugin = $this->pluginManager->get($name);
            $plugin();

            $this->plugins[$name] = $plugin;
        }
    }

    /**
     * Učitava WordPress.
     */
    private function includes()
    {
        /** @noinspection PhpUnusedLocalVariableInspection */
        $table_prefix = 'wp_';

        /** @noinspection PhpUnusedLocalVariableInspection */
        global $wc_cpdf, $extensions_uri, $nav_elements, $extensions_url,
               $revSliderVersion, $timeline_express_base;

        require ABSPATH . 'wp-settings.php';
    }
}

==> ep-framework-wordpress-1.2.9-a25964.tar: src/Middleware/Bootstrap.php <==
<?php
namespace Ep\Wp\Middleware;

use Ep\Middleware\BaseUrl;
use Ep\Wp\Plugin\PluginInterface;
use Ep\Wp\Plugin\PluginManager;
use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ServerRequestInterface;
use Zend\Db\Adapter\AdapterInterface;
use Zend\Db\Adapter\Driver\Pdo\Pdo;

/**
 * Postavlja WordPress okruženje.
 *
 * @package Ep\Wp\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Bootstrap implements MiddlewareInterface
{
    /** @var array */
    private $config;
    /** @var AdapterInterface */
    private $db;
    /** @var PluginManager */
    private $pluginManager;
    /** @var PluginInterface  */
    private $plugins = [];

    /**
     * Config constructor.
     *
     * @param array $config
     * @param AdapterInterface $db
     */
    public function __construct(array $config, AdapterInterface $db, PluginManager $pluginManager)
    {
        $this->config = $config;
        $this->db     = $db;
        $this->pluginManager = $pluginManager;
    }

    /**
     * Inicijalizira WordPress.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        $this->database();
        $this->paths($request);
        $this->globals();
        $this->plugins();
        $this->includes();

        return $handler->handle($request);
    }

    /**
     * Postavlja bazu podataka.
     */
    private function database()
    {
        /** @var Pdo $driver */
        $driver = $this->db->getDriver();
        $params = $driver->getConnection()->getConnectionParameters();

        define('DB_NAME', $params['database'] ?? '');
        define('DB_USER', $params['username'] ?? '');
        define('DB_PASSWORD', $params['password'] ?? '');
        define('DB_HOST', $params['hostname'] ?? '');
        define('DB_CHARSET', 'utf8mb4');
        define('DB_COLLATE', 'utf8mb4_general_ci');
    }

    /**
     * Postavlja putanje i url-ove.
     *
     * @param ServerRequestInterface $request
     */
    private function paths(ServerRequestInterface $request)
    {
        $baseUrl = $request->getAttribute(BaseUrl::BASE_URL, '/');
        $baseUrl = preg_replace('#/wp(/wp-admin)?/?#', '', $baseUrl);

        $home = $request->getUri()
                        ->withPath($baseUrl)
                        ->withQuery('');

        define('WP_HOME', rtrim($home, '/'));
        define('WP_SITEURL', WP_HOME . '/wp');

        define('WP_CONTENT_DIR', dirname(ABSPATH) . '/wp-content');
        define('WP_CONTENT_URL', WP_HOME . '/wp-content');
    }

    /**
     * Inicijalizira globalne varijable.
     */
    private function globals()
    {
        define('WP_DEBUG', $this->config['debug'] ?? false);
    }

    /**
     * Inicijalizira vanjske pluginove.
     */
    private function plugins()
    {
        require_once ABSPATH . 'wp-includes/plugin.php';

        foreach ($this->config['plugins'] as $key => $value) {
            if (false === $value) {
                continue;
            }

            $name = is_numeric($key) ? $value : $key;

            if (isset($this->config['plugins'][$name]) && false === $this->config['plugins'][$name]) {
                continue;
            }

            $plugin = $this->pluginManager->get($name);
            $plugin();

            $this->plugins[$name] = $plugin;
        }
    }

    /**
     * Učitava WordPress.
     */
    private function includes()
    {
        /** @noinspection PhpUnusedLocalVariableInspection */
        $table_prefix = 'wp_';

        /** @noinspection PhpUnusedLocalVariableInspection */
        global $wc_cpdf, $extensions_uri, $nav_elements, $extensions_url,
               $revSliderVersion, $timeline_express_base;

        require ABSPATH . 'wp-settings.php';
    }
}
